@@ -14,6 +14,6 @@ alternateColorSpace <- NULL
   ourColorSpace <<- colorspace::RGB(runif(n), runif(n), runif(n))
   ourColorSpace <<- as(ourColorSpace, "LAB")
 
-  # Alternate color palette
-  alternateColorSpace <<- t(unique(col2rgb(hue_pal(l=60:100)(n))))
+###  # Alternate color palette
+###  alternateColorSpace <<- t(unique(col2rgb(hue_pal(l=60:100)(n))))
 }
